//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B4:WSSTR Confirmation","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C4:WSSTR ObjectBox","Ʈ ڽ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D4:WSSTR ProjectSettings","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E4:WSSTR New project","Ʈ  ۼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F4:WSSTR Open project","Ʈ б");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G4:WSSTR Save project","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H4:WSSTR Close project","Ʈ ݱ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","I4:WSSTR New application window","  ۼ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","J4:WSSTR Open application window"," б");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K4:WSSTR Save application window"," ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","L4:WSSTR Delete instance","/Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","M4:WSSTR Properties","Ƽ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N4:WSSTR Procedures","ν ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O4:WSSTR Display the object box","Ʈ ڽ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P4:WSSTR Project settings","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q4:WSSTR Build all"," ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q4:WSSTR Cancel"," ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R4:WSSTR Execute","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S4:WSSTR Find instances","/νϽ ˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","T4:WSSTR Find files"," ˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","U4:WSSTR Help","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V4:WSSTR  File(F)"," (F)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W4:WSSTR New window(N)         :m11:N,Open window(O):m12:O,Save window(S):m13:S,Save as(R):m14:R,Save all(A):m15:A,SP,Exit(X):m16:X"," (N)      :m11:N:0:$(WSDIR)/sys/pixmaps/wcreate.png, (O):m12:O:0:$(WSDIR)/sys/pixmaps/wload.png, (S):m13:S:0:$(WSDIR)/sys/pixmaps/wsave.png, ٸ ̸ (R):m14:R,  (A):m15:A,SP, (X):m16:X:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X4:WSSTR  Edit(E)"," (E)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y4:WSSTR Copy(C):m21:C,Paste(P):m22:P,SP,Display(I):m27:I,Find(F):m28:F,Delete(D):m23:D,SP,Properties(R):m24:R,Procedures:{List up(L):m25:L,New procedure(N):m251:N,Properties(S):m252:S,Edit(E):m253:E,Delete(X):m254:X},Attributes(A):m26:A,Files(L):m29:L"," (U):m291:U:1,(C):m21:C,ٿֱ(P):m22:P,SP,ǥ(I):m27:I,νϽ ˻(F):m28:F,(D):m23:D,SP,Ƽ (R):m24:R,ν :{ν ϶(L):m25:L,ν  (N):m251:N,ν (S):m252:S,ν (E):m253:E,ν (X):m254:X},⺻(A):m26:A, ϶(L):m29:L");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z4:WSSTR  Build(B)"," (B)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Execute(X):m36:X,Execute with Trace(T):m39:T,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","(C)    :m31:C, (B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,(R):m33:R,Ŭ(E):m34:E,SP,(D):m35:D,(X):m36:X:0:$(WSDIR)/sys/pixmaps/run.png,Ʈ̽ (T):m39:T,SP,ҽ (G):m37:G, (I):m38:I");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","b4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Abort(X):m36:X,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","(C)    :m31:C, (B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,(R):m33:R,Ŭ(E):m34:E,SP,(D):m35:D,(X):m36:X:0:$(WSDIR)/sys/pixmaps/runx.png,SP,ҽ (G):m37:G, (I):m38:I");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c4:WSSTR  View(V)"," (V)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Terminal(T):m45:T","޴(D) :m46:D,ν(I) :m47:I,νϽ (E) :m48:E,Ŭ Ʈ(L) :m49:L,Ʈ ڽ(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,Ʈ(C):m42:C, (B):m43:B,SP,͹̳(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","e4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Find Files(F):m44:F,Terminal(T):m45:T","޴(D) :m46:D,ν(I) :m47:I,νϽ (E) :m48:E,Ŭ Ʈ(L) :m49:L,Ʈ ڽ(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,Ʈ(C):m42:C, (B):m43:B,SP, ˻(F):m44:F,͹̳(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f4:WSSTR  Project(P)"," Ʈ(P)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","g4:WSSTR New project(N)        :m51:N,Open project(O):m52:O,Save project(S):m53:S,Rename project(R):m54:R,SP,Project settings(E):m55:E,SP,Close project(C):m56:C","Ʈ  (N)      :m51:N:0:$(WSDIR)/sys/pixmaps/pcreate.png,Ʈ (O) :m52:O:0:$(WSDIR)/sys/pixmaps/pload.png,Ʈ (S):m53:S:0:$(WSDIR)/sys/pixmaps/psave.png,Ʈ ٸ ̸ (R):m54:R,SP,Ʈ (E):m55:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,Ʈ ݱ(C):m56:C:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","h4:WSSTR  Option(O)"," ɼ(O)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","i4:WSSTR Environment(E)    :m61:E,SP,Colors(C):m62:C,Fonts(F):m63:F,Look and Feel(L):m64:L","ȯ漳(E)      :m61:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP, (C):m62:C,۲ (F):m63:F,Ѻ(L):m64:L");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","j4:WSSTR  Help(H)"," (H)");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","k4:WSSTR Index(I):m81:I,Reference(R)     :m82:R,User's guide(U):m83:U,About WideStudio(V):m84:V,License(L):m85:L","(I):m81:I:0:$(WSDIR)/sys/pixmaps/help.png,۷(R)     :m82:R,(U):m83:U,(V):m84:V,̼(L):m85:L");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l4:WSSTR Please specify a window to save."," 带 ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","m4:WSSTR Continue saving?"," մϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","n4:WSSTR Please specify some instances to copy."," νϽ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o4:WSSTR Please specify a instance to paste.","ٿ ġ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p4:WSSTR Some instances are selected to paste.\nPlease specify a instance.","ٿ ġ ΰ̻ ϼ̽ϴ.\nϳ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","q4:WSSTR Please select the instance to delete."," νϽ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","r4:WSSTR Delete instance: ","νϽ: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","s4:WSSTR  ?"," / Ͻðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","t4:WSSTR Please specify a instance to display.","ǥ νϽ ּ. ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","u4:WSSTR There is no instance for search.","˻εǴ Ʈ/νϽ ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","v4:WSSTR Please specify a application window to compile.","   ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","w4:WSSTR Please check the debugger settings or confirm whether the project is build.","  ùٸ, ũǾ ִ Ȯּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","x4:WSSTR Can not execute the class library...","̺귯  մϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","y4:WSSTR Can not execute the load module.\nPlease confirm whether the project is collect or built.","ε մϴ.\nƮ ùٸ, ũǾ ִ Ȯּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","z4:WSSTR Please specify a application window to generate source code.","ҽ   ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A4:WSSTR Please wait for a while to start web browser.."," ֽϴ. ٷּ...");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B4:WSSTR NoName","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C4:WSSTR Unexpected error occurred in reading the project files...","Ʈ ⿡  ߻߽ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D4:WSSTR Can not open File: ",": ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E4:WSSTR  .","\n ⿡  ߻߽ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F4:WSSTR Can not save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G4:WSSTR  ."," ¿ ߽ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H4:WSSTR The project was modified.\nSave it?","Ʈ Ǿ ֽϴ.\nϽðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","I4:WSSTR Abort saving the application window.","  ߴϰڽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","J4:WSSTR Some application windows were modified \nSave them?"," Ǿ ֽϴ.\nϽðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K4:WSSTR The project has no name.\nName the project and save it?","Ʈ ̸ ϴ.\n̸  Ͻðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","L4:WSSTR Exit the application builder?"," ðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","M4:WSSTR Sorry, under construction...","˼ Դϴ...");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N4:WSSTR Faild to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O4:WSSTR Do you continue?"," ¿ ߽ϴ.  Ͻðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P4:WSSTR \",\n","/ ۼϰڽϴ.\",\n");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q4:WSSTR No project is specified.\nGenerate a new project?","Ʈ  ʽϴ.\nƮ ,  Ʈ  ּ.\nƮ  ڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R4:WSSTR Please specify a keyward to search files.","Ͽ ԵǴ ڷ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S4:WSSTR No editor is specified.\nPlease confirm the project settings and specify the editor.","Ͱ  ʽϴ. \nƮ ͸  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S4:WSSTR No editor option is specified.\nPlease confirm the project settings and specify the editor.","Ϳɼ  ʽϴ.\nƮ Ϳɼ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","T4:WSSTR New project","Ʈ  ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","U4:WSSTR < Back,Next >,Finish","< ڿ,  >,");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V4:WSSTR Project name","Ʈ ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W4:WSSTR Working dir","۾ ͸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X4:WSSTR Project type","Ʈ ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y4:WSSTR  Normal application","  ø̼");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z4:WSSTR  Class library component"," Ŭ ̺귯 Ʈ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W4:WSSTR New application window","  ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X4:WSSTR < Back,Next >,Finish","< ڿ,  >,");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y4:WSSTR Type","Ÿ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z4:WSSTR  Normal window","  ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a4:WSSTR  Class"," Ŭ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","b4:WSSTR Project","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","c4:WSSTR  Add to project"," Ʈ Ѵ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","d4:WSSTR Name","̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","e4:WSSTR Please specify a instance name to search.","˻(νϽ̸) ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f4:WSSTR Please specify a value of the property to search instance.","˻(Ƽ) ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","f4:WSSTR Please specify a property name likes [WSN...] to search instance.","WSN...  ۵Ǵ Ƽ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","g4:WSSTR Please specify search condition.","˻  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","h4:WSSTR No instance."," νϽ ãҽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","i4:WSSTR Find instances","νϽ ˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","j4:WSSTR Find","˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","k4:WSSTR Instance name,Properties,Procedures","νϽ ̸,Ƽ,ν");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","l4:WSSTR InstanceName","νϽ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","m4:WSSTR Comparison","˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","n4:WSSTR  Complete equal","ġ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","o4:WSSTR PropertyName","Ƽ ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","p4:WSSTR Value","Ƽ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","q4:WSSTR ProcedureName","ν ̸");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","r4:WSSTR FunctionName","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","s4:WSSTR Direction","˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","t4:WSSTR  Downward"," Ʒ ˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","u4:WSSTR  Upward","  ˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","v4:WSSTR Find files"," ˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","w4:WSSTR < Back,Find, Find","< ڷ,˻, ˻");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","x4:WSSTR Dir:","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","y4:WSSTR File type:"," Ÿ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","z4:WSSTR Keyword:","ԵǴ ڿ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","A4:WSSTR Faild to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","B4:WSSTR .","\n ¿ ߽ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","C4:WSSTR Delete instance:","νϽ:");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","D4:WSSTR ?","\nص ϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","E4:WSSTR Add application window: ",": ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","F4:WSSTR  to the project?","  Ʈ մϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","G4:WSSTR Remove application window: ",": ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","H4:WSSTR  from the project?","  Ʈ  մϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","I4:WSSTR Faild to read file:",": ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","J4:WSSTR .\nDo you stop reading?","\n б⿡  ߻߽ϴ.\nб⸦ Ͻðڽϱ?");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","K4:WSSTR Faild to open File: ",": ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","L4:WSSTR .","\n/  ߽ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","M4:WSSTR Faild to write File: ",": ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","N4:WSSTR .","\n   ߻߽ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","O4:WSSTR Invalid name: ","ȿ ̸: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P4:WSSTR .\nPlease specify a usable name in C/C++ variables.","\n C/C++ ̿Ҽִ  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P4:WSSTR .\nAlready used by project name.",".\nƮ ٸ ̸  ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","P4:WSSTR .\nCan not use array name.",".\nĸ  մϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Q4:WSSTR Can not generate the specified class: "," Ŭ: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","R4:WSSTR ."," / ϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","S4:WSSTR Can not change the specified class: "," Ŭ: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","T4:WSSTR  to window type.\nPlease specify a class of window/dialog base."," /  մϴ.\n  ⺻ Ŭ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","U4:WSSTR Can not paste the instance on the specified instance: ","νϽ: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","V4:WSSTR .","  ؼ\nٸ νϽ ٿ մϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","W4:WSSTR Can not paste the specified instance: ","νϽ: ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","X4:WSSTR ,\nbecause it overlap the source and the destication..."," İ ֽϴ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y4:WSSTR Locale type"," ");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y4:WSSTR Language","");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Y4:WSSTR Templates","ø");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","Z4:WSSTR Can not read file:",":");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a4:WSSTR .","\n /  ϴ. $(WSDIR)   Ȯ ּ.");
  WSGIappLocaleSet()->setLocaleString("ko_KR.euckr","a4:WSSTR Look and Feel","Ѻ");
